## Load libraries
library(readr)
library(mgcv)
library(ggplot2)
library(grid)
library(gridExtra)

## Load Greek data set and separate males and females
mydata <- read_csv("shapeData-GR.csv", show_col_types=FALSE)
mydata_m<-mydata[mydata$sex==1,]
mydata_f<-mydata[mydata$sex==2,]

## Calculate GAMs predicting lower endplate variables for the males based on age
## and save model summaries
modm_1 <- gam(LiArea ~ s(age), data=mydata_m, method = "REML")
sm1<-summary(modm_1)
modm_2 <- gam(LiPer ~ s(age), data=mydata_m, method = "REML")
sm2<-summary(modm_2)
modm_3 <- gam(LeArea ~ s(age), data=mydata_m, method = "REML")
sm3<-summary(modm_3)
modm_4 <- gam(LePer ~ s(age), data=mydata_m, method = "REML")
sm4<-summary(modm_4)
modm_5 <- gam(LieArea ~ s(age), data=mydata_m, method = "REML")
sm5<-summary(modm_5)
modm_6 <- gam(LieAreaRatio ~ s(age), data=mydata_m, method = "REML")
sm6<-summary(modm_6)
modm_7 <- gam(LiArPerIndex ~ s(age), data=mydata_m, method = "REML")
sm7<-summary(modm_7)
modm_8 <- gam(LeArPerIndex ~ s(age), data=mydata_m, method = "REML")
sm8<-summary(modm_8)
modm_9 <- gam(LieArPerIndex ~ s(age), data=mydata_m, method = "REML")
sm9<-summary(modm_9)

## Calculate GAMs predicting upper endplate variables for the males based on age
## and save model summaries
modm_10 <- gam(UiArea ~ s(age), data=mydata_m, method = "REML")
sm10<-summary(modm_10)
modm_11 <- gam(UiPer ~ s(age), data=mydata_m, method = "REML")
sm11<-summary(modm_11)
modm_12 <- gam(UeArea ~ s(age), data=mydata_m, method = "REML")
sm12<-summary(modm_12)
modm_13 <- gam(UePer ~ s(age), data=mydata_m, method = "REML")
sm13<-summary(modm_13)
modm_14 <- gam(UieArea ~ s(age), data=mydata_m, method = "REML")
sm14<-summary(modm_14)
modm_15 <- gam(UieAreaRatio ~ s(age), data=mydata_m, method = "REML")
sm15<-summary(modm_15)
modm_16 <- gam(UiArPerIndex ~ s(age), data=mydata_m, method = "REML")
sm16<-summary(modm_16)
modm_17 <- gam(UeArPerIndex ~ s(age), data=mydata_m, method = "REML")
sm17<-summary(modm_17)
modm_18 <- gam(UieArPerIndex ~ s(age), data=mydata_m, method = "REML")
sm18<-summary(modm_18)

## Plot models for males' lower endplate variables
png("GAM_pVar_Males_Lower.png", width=1500, height=1500, res=300)
grid.arrange(
  ggplot(mydata_m, aes(age, LiArea)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(age, LiPer)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(age, LeArea)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(age, LePer)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(age, LieArea)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(age, LieAreaRatio)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(age, LiArPerIndex)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(age, LeArPerIndex)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(age, LieArPerIndex)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ncol=3, nrow=3, top ="GAMs predicting male lower endplate variables from age")
dev.off()
## Plot models for males' upper endplate variables
png("GAM_pVar_Males_Upper.png", width=1500, height=1500, res=300)
grid.arrange(
  ggplot(mydata_m, aes(age, UiArea)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(age, UiPer)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(age, UeArea)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(age, UePer)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(age, UieArea)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(age, UieAreaRatio)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(age, UiArPerIndex)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(age, UeArPerIndex)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(age, UieArPerIndex)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ncol=3, nrow=3, top ="GAMs predicting male upper endplate variables from age")
dev.off()

## Export model statistics to csv
statistics.table1=matrix(data=c(sm1$r.sq, sm1$dev.expl, sm1$chi.sq[[1]], sm1$s.pv, 
                                sm2$r.sq, sm2$dev.expl, sm2$chi.sq[[1]], sm2$s.pv,
                                sm3$r.sq, sm3$dev.expl, sm3$chi.sq[[1]], sm3$s.pv,
                                sm4$r.sq, sm4$dev.expl, sm4$chi.sq[[1]], sm4$s.pv,
                                sm5$r.sq, sm5$dev.expl, sm5$chi.sq[[1]], sm5$s.pv,
                                sm6$r.sq, sm6$dev.expl, sm6$chi.sq[[1]], sm6$s.pv,
                                sm7$r.sq, sm7$dev.expl, sm7$chi.sq[[1]], sm7$s.pv,
                                sm8$r.sq, sm8$dev.expl, sm8$chi.sq[[1]], sm8$s.pv,
                                sm9$r.sq, sm9$dev.expl, sm9$chi.sq[[1]], sm9$s.pv,
                                sm10$r.sq, sm10$dev.expl, sm10$chi.sq[[1]], sm10$s.pv, 
                                sm11$r.sq, sm11$dev.expl, sm11$chi.sq[[1]], sm11$s.pv,
                                sm12$r.sq, sm12$dev.expl, sm12$chi.sq[[1]], sm12$s.pv,
                                sm13$r.sq, sm13$dev.expl, sm13$chi.sq[[1]], sm13$s.pv,
                                sm14$r.sq, sm14$dev.expl, sm14$chi.sq[[1]], sm14$s.pv,
                                sm15$r.sq, sm15$dev.expl, sm15$chi.sq[[1]], sm15$s.pv,
                                sm16$r.sq, sm16$dev.expl, sm16$chi.sq[[1]], sm16$s.pv,
                                sm17$r.sq, sm17$dev.expl, sm17$chi.sq[[1]], sm17$s.pv,
                                sm18$r.sq, sm18$dev.expl, sm18$chi.sq[[1]], sm18$s.pv), nrow=18, ncol=4, byrow=TRUE, 
                         dimnames=list(c("LiArea", "LiPer", "LeArea", "LePer", "LieArea", "LieAreaRatio", "LiArPerIndex", 
                                         "LeArPerIndex", "LieArPerIndex", "UiArea", "UiPer", "UeArea", "UePer", "UieArea",
                                         "UieAreaRatio", "UiArPerIndex", "UeArPerIndex", "UieArPerIndex"), 
                                       c("R2_adj", "Dev. Explained", "F-stat", "p-value")))
write.csv(statistics.table1, file="GAM_pVar_Males.csv")

####
####

## Calculate GAMs predicting lower endplate variables for the females based on age
## and save model summaries
modf_1 <- gam(LiArea ~ s(age), data=mydata_f, method = "REML")
sf1<-summary(modf_1)
modf_2 <- gam(LiPer ~ s(age), data=mydata_f, method = "REML")
sf2<-summary(modf_2)
modf_3 <- gam(LeArea ~ s(age), data=mydata_f, method = "REML")
sf3<-summary(modf_3)
modf_4 <- gam(LePer ~ s(age), data=mydata_f, method = "REML")
sf4<-summary(modf_4)
modf_5 <- gam(LieArea ~ s(age), data=mydata_f, method = "REML")
sf5<-summary(modf_5)
modf_6 <- gam(LieAreaRatio ~ s(age), data=mydata_f, method = "REML")
sf6<-summary(modf_6)
modf_7 <- gam(LiArPerIndex ~ s(age), data=mydata_f, method = "REML")
sf7<-summary(modf_7)
modf_8 <- gam(LeArPerIndex ~ s(age), data=mydata_f, method = "REML")
sf8<-summary(modf_8)
modf_9 <- gam(LieArPerIndex ~ s(age), data=mydata_f, method = "REML")
sf9<-summary(modf_9)

## Calculate GAMs predicting upper endplate variables for the females based on age
## and save model summaries
modf_10 <- gam(UiArea ~ s(age), data=mydata_f, method = "REML")
sf10<-summary(modf_10)
modf_11 <- gam(UiPer ~ s(age), data=mydata_f, method = "REML")
sf11<-summary(modf_11)
modf_12 <- gam(UeArea ~ s(age), data=mydata_f, method = "REML")
sf12<-summary(modf_12)
modf_13 <- gam(UePer ~ s(age), data=mydata_f, method = "REML")
sf13<-summary(modf_13)
modf_14 <- gam(UieArea ~ s(age), data=mydata_f, method = "REML")
sf14<-summary(modf_14)
modf_15 <- gam(UieAreaRatio ~ s(age), data=mydata_f, method = "REML")
sf15<-summary(modf_15)
modf_16 <- gam(UiArPerIndex ~ s(age), data=mydata_f, method = "REML")
sf16<-summary(modf_16)
modf_17 <- gam(UeArPerIndex ~ s(age), data=mydata_f, method = "REML")
sf17<-summary(modf_17)
modf_18 <- gam(UieArPerIndex ~ s(age), data=mydata_f, method = "REML")
sf18<-summary(modf_18)

## Plot models for females' lower endplate variables
png("GAM_pVar_Females_Lower.png", width=1500, height=1500, res=300)
grid.arrange(
  ggplot(mydata_f, aes(age, LiArea)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(age, LiPer)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(age, LeArea)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(age, LePer)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(age, LieArea)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(age, LieAreaRatio)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(age, LiArPerIndex)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(age, LeArPerIndex)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(age, LieArPerIndex)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ncol=3, nrow=3, top ="GAMs predicting female lower endplate variables from age")
dev.off()
## Plot models for females' upper endplate variables
png("GAM_pVar_Females_Upper.png", width=1500, height=1500, res=300)
grid.arrange(
  ggplot(mydata_f, aes(age, UiArea)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(age, UiPer)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(age, UeArea)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(age, UePer)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(age, UieArea)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(age, UieAreaRatio)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(age, UiArPerIndex)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(age, UeArPerIndex)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(age, UieArPerIndex)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ncol=3, nrow=3, top ="GAMs predicting female upper endplate variables from age")
dev.off()

## Export model statistics to csv
statistics.table2=matrix(data=c(sf1$r.sq, sf1$dev.expl, sf1$chi.sq[[1]], sf1$s.pv, 
                                sf2$r.sq, sf2$dev.expl, sf2$chi.sq[[1]], sf2$s.pv,
                                sf3$r.sq, sf3$dev.expl, sf3$chi.sq[[1]], sf3$s.pv,
                                sf4$r.sq, sf4$dev.expl, sf4$chi.sq[[1]], sf4$s.pv,
                                sf5$r.sq, sf5$dev.expl, sf5$chi.sq[[1]], sf5$s.pv,
                                sf6$r.sq, sf6$dev.expl, sf6$chi.sq[[1]], sf6$s.pv,
                                sf7$r.sq, sf7$dev.expl, sf7$chi.sq[[1]], sf7$s.pv,
                                sf8$r.sq, sf8$dev.expl, sf8$chi.sq[[1]], sf8$s.pv,
                                sf9$r.sq, sf9$dev.expl, sf9$chi.sq[[1]], sf9$s.pv,
                                sf10$r.sq, sf10$dev.expl, sf10$chi.sq[[1]], sf10$s.pv, 
                                sf11$r.sq, sf11$dev.expl, sf11$chi.sq[[1]], sf11$s.pv,
                                sf12$r.sq, sf12$dev.expl, sf12$chi.sq[[1]], sf12$s.pv,
                                sf13$r.sq, sf13$dev.expl, sf13$chi.sq[[1]], sf13$s.pv,
                                sf14$r.sq, sf14$dev.expl, sf14$chi.sq[[1]], sf14$s.pv,
                                sf15$r.sq, sf15$dev.expl, sf15$chi.sq[[1]], sf15$s.pv,
                                sf16$r.sq, sf16$dev.expl, sf16$chi.sq[[1]], sf16$s.pv,
                                sf17$r.sq, sf17$dev.expl, sf17$chi.sq[[1]], sf17$s.pv,
                                sf18$r.sq, sf18$dev.expl, sf18$chi.sq[[1]], sf18$s.pv), nrow=18, ncol=4, byrow=TRUE, 
                         dimnames=list(c("LiArea", "LiPer", "LeArea", "LePer", "LieArea", "LieAreaRatio", "LiArPerIndex", 
                                         "LeArPerIndex", "LieArPerIndex", "UiArea", "UiPer", "UeArea", "UePer", "UieArea",
                                         "UieAreaRatio", "UiArPerIndex", "UeArPerIndex", "UieArPerIndex"), 
                                       c("R2_adj", "Dev. Explained", "F-stat", "p-value")))
write.csv(statistics.table2, file="GAM_pVar_Females.csv")

## Plot best models for males and females
png("GAM_pVal_Models_per_Sex.png", width=1800, height=2400, res=300)
grid.arrange(
  ggplot(mydata_m, aes(age, LeArea)) + geom_point(size=0.5, colour="blue") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ggplot(mydata_f, aes(age, LeArea)) + geom_point(size=0.5, colour="red") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ggplot(mydata_m, aes(age, UeArea)) + geom_point(size=0.5, colour="blue") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ggplot(mydata_f, aes(age, UeArea)) + geom_point(size=0.5, colour="red") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ggplot(mydata_m, aes(age, LePer)) + geom_point(size=0.5, colour="blue") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ggplot(mydata_f, aes(age, LePer)) + geom_point(size=0.5, colour="red") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ggplot(mydata_m, aes(age, UePer)) + geom_point(size=0.5, colour="blue") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ggplot(mydata_f, aes(age, UePer)) + geom_point(size=0.5, colour="red") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ggplot(mydata_m, aes(age, LieArea)) + geom_point(size=0.5, colour="blue") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ggplot(mydata_f, aes(age, LieArea)) + geom_point(size=0.5, colour="red") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ggplot(mydata_m, aes(age, UieArea)) + geom_point(size=0.5, colour="blue") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ggplot(mydata_f, aes(age, UieArea)) + geom_point(size=0.5, colour="red") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ggplot(mydata_m, aes(age, LieAreaRatio)) + geom_point(size=0.5, colour="blue") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ggplot(mydata_f, aes(age, LieAreaRatio)) + geom_point(size=0.5, colour="red") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ggplot(mydata_m, aes(age, UieAreaRatio)) + geom_point(size=0.5, colour="blue") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ggplot(mydata_f, aes(age, UieAreaRatio)) + geom_point(size=0.5, colour="red") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ggplot(mydata_m, aes(age, LeArPerIndex)) + geom_point(size=0.5, colour="blue") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ggplot(mydata_f, aes(age, LeArPerIndex)) + geom_point(size=0.5, colour="red") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ggplot(mydata_m, aes(age, UeArPerIndex)) + geom_point(size=0.5, colour="blue") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ggplot(mydata_f, aes(age, UeArPerIndex)) + geom_point(size=0.5, colour="red") + geom_smooth(method = "gam", formula = y ~s(x), colour="black") 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=8), axis.title.y = element_text(size=8), axis.text.y = element_text(size=8)),
  ncol=4, nrow=5, top ="")
grid.draw(gridtext::richtext_grob(text = 'GAMs predicting endplate variables from age in <span style="color:blue">males</span> and <span style="color:red">females</span>',
                                  x = unit(0.5, 'npc'), y = unit(0.985, 'npc'), hjust=.5))
dev.off()

################################################################################
################################################################################
################################################################################
################################################################################

## Calculate GAMs predicting age for the males based on lower endplate variables
## and save model summaries
modm_1 <- gam(age ~ s(LiArea), data=mydata_m, method = "REML")
sm1<-summary(modm_1)
modm_2 <- gam(age ~ s(LiPer), data=mydata_m, method = "REML")
sm2<-summary(modm_2)
modm_3 <- gam(age ~ s(LeArea), data=mydata_m, method = "REML")
sm3<-summary(modm_3)
modm_4 <- gam(age ~ s(LePer), data=mydata_m, method = "REML")
sm4<-summary(modm_4)
modm_5 <- gam(age ~ s(LieArea), data=mydata_m, method = "REML")
sm5<-summary(modm_5)
modm_6 <- gam(age ~ s(LieAreaRatio), data=mydata_m, method = "REML")
sm6<-summary(modm_6)
modm_7 <- gam(age ~ s(LiArPerIndex), data=mydata_m, method = "REML")
sm7<-summary(modm_7)
modm_8 <- gam(age ~ s(LeArPerIndex), data=mydata_m, method = "REML")
sm8<-summary(modm_8)
modm_9 <- gam(age ~ s(LieArPerIndex), data=mydata_m, method = "REML")
sm9<-summary(modm_9)

## Calculate GAMs predicting age for the males based on upper endplate variables
## and save model summaries
modm_10 <- gam(age ~ s(UiArea), data=mydata_m, method = "REML")
sm10<-summary(modm_10)
modm_11 <- gam(age ~ s(UiPer), data=mydata_m, method = "REML")
sm11<-summary(modm_11)
modm_12 <- gam(age ~ s(UeArea), data=mydata_m, method = "REML")
sm12<-summary(modm_12)
modm_13 <- gam(age ~ s(UePer), data=mydata_m, method = "REML")
sm13<-summary(modm_13)
modm_14 <- gam(age ~ s(UieArea), data=mydata_m, method = "REML")
sm14<-summary(modm_14)
modm_15 <- gam(age ~ s(UieAreaRatio), data=mydata_m, method = "REML")
sm15<-summary(modm_15)
modm_16 <- gam(age ~ s(UiArPerIndex), data=mydata_m, method = "REML")
sm16<-summary(modm_16)
modm_17 <- gam(age ~ s(UeArPerIndex), data=mydata_m, method = "REML")
sm17<-summary(modm_17)
modm_18 <- gam(age ~ s(UieArPerIndex), data=mydata_m, method = "REML")
sm18<-summary(modm_18)

## Plot models for males' lower endplate variables
png("GAM_pAge_Males_Lower.png", width=1500, height=1500, res=300)
grid.arrange(
  ggplot(mydata_m, aes(LiArea, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7))
  + scale_x_continuous(breaks = c(400, 600, 800, 1000), limits = c(390, 1010)),
  ggplot(mydata_m, aes(LiPer, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7))
  + scale_x_continuous(breaks = c(80, 90, 100, 110)),
  ggplot(mydata_m, aes(LeArea, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7))
  + scale_x_continuous(breaks = c(1000, 1250, 1500, 1750)),
  ggplot(mydata_m, aes(LePer, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7))
  + scale_x_continuous(breaks = c(110, 130, 150, 170)),
  ggplot(mydata_m, aes(LieArea, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(LieAreaRatio, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(LiArPerIndex, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(LeArPerIndex, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(LieArPerIndex, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
ncol=3, nrow=3, top ="GAMs predicting age from male lower endplate variables")
dev.off()
## Plot models for males' upper endplate variables
png("GAM_pAge_Males_Upper.png", width=1500, height=1500, res=300)
grid.arrange(
  ggplot(mydata_m, aes(UiArea, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7))
  + scale_x_continuous(breaks = c(400, 600, 800, 1000), limits = c(390, 1010)),
  ggplot(mydata_m, aes(UiPer, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7))
  + scale_x_continuous(breaks = c(80, 90, 100, 110)),
  ggplot(mydata_m, aes(UeArea, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7))
  + scale_x_continuous(breaks = c(850, 1100, 1350, 1600)),
  ggplot(mydata_m, aes(UePer, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7))
  + scale_x_continuous(breaks = c(110, 130, 150, 170)),
  ggplot(mydata_m, aes(UieArea, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(UieAreaRatio, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(UiArPerIndex, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7))
  + scale_x_continuous(breaks = c(0.75, 0.8, 0.85, 0.9, 0.95)),
  ggplot(mydata_m, aes(UeArPerIndex, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_m, aes(UieArPerIndex, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ncol=3, nrow=3, top ="GAMs predicting age from male upper endplate variables")
dev.off()

## Export model statistics to csv
statistics.table3=matrix(data=c(sm1$r.sq, sm1$dev.expl, sm1$chi.sq[[1]], sm1$s.pv, 
                                sm2$r.sq, sm2$dev.expl, sm2$chi.sq[[1]], sm2$s.pv,
                                sm3$r.sq, sm3$dev.expl, sm3$chi.sq[[1]], sm3$s.pv,
                                sm4$r.sq, sm4$dev.expl, sm4$chi.sq[[1]], sm4$s.pv,
                                sm5$r.sq, sm5$dev.expl, sm5$chi.sq[[1]], sm5$s.pv,
                                sm6$r.sq, sm6$dev.expl, sm6$chi.sq[[1]], sm6$s.pv,
                                sm7$r.sq, sm7$dev.expl, sm7$chi.sq[[1]], sm7$s.pv,
                                sm8$r.sq, sm8$dev.expl, sm8$chi.sq[[1]], sm8$s.pv,
                                sm9$r.sq, sm9$dev.expl, sm9$chi.sq[[1]], sm9$s.pv,
                                sm10$r.sq, sm10$dev.expl, sm10$chi.sq[[1]], sm10$s.pv, 
                                sm11$r.sq, sm11$dev.expl, sm11$chi.sq[[1]], sm11$s.pv,
                                sm12$r.sq, sm12$dev.expl, sm12$chi.sq[[1]], sm12$s.pv,
                                sm13$r.sq, sm13$dev.expl, sm13$chi.sq[[1]], sm13$s.pv,
                                sm14$r.sq, sm14$dev.expl, sm14$chi.sq[[1]], sm14$s.pv,
                                sm15$r.sq, sm15$dev.expl, sm15$chi.sq[[1]], sm15$s.pv,
                                sm16$r.sq, sm16$dev.expl, sm16$chi.sq[[1]], sm16$s.pv,
                                sm17$r.sq, sm17$dev.expl, sm17$chi.sq[[1]], sm17$s.pv,
                                sm18$r.sq, sm18$dev.expl, sm18$chi.sq[[1]], sm18$s.pv), nrow=18, ncol=4, byrow=TRUE, 
                      dimnames=list(c("LiArea", "LiPer", "LeArea", "LePer", "LieArea", "LieAreaRatio", "LiArPerIndex", 
                                      "LeArPerIndex", "LieArPerIndex", "UiArea", "UiPer", "UeArea", "UePer", "UieArea",
                                      "UieAreaRatio", "UiArPerIndex", "UeArPerIndex", "UieArPerIndex"), 
                                      c("R2_adj", "Dev. Explained", "F-stat", "p-value")))
write.csv(statistics.table3, file="GAM_pAge_Males.csv")

## Calculate Multivariate GAM for males using LeArPerIndex and LieArea variables
multi_mL<-gam(age ~ s(LeArPerIndex) + s(LieArea), data=mydata_m, method = "REML")
smulti_mL<-summary(multi_mL)

## Calculate Multivariate GAM for males using UieAreaRatio, UeArPerIndex, and UieArea variables
multi_mU<-gam(age ~ s(UieAreaRatio) + s(UeArPerIndex) + s(UieArea), data=mydata_m, method = "REML")
smulti_mU<-summary(multi_mU)

####
####

## Calculate GAMs predicting age for the females based on lower endplate variables
## and save model summaries
modf_1 <- gam(age ~ s(LiArea), data=mydata_f, method = "REML")
sf1<-summary(modf_1)
modf_2 <- gam(age ~ s(LiPer), data=mydata_f, method = "REML")
sf2<-summary(modf_2)
modf_3 <- gam(age ~ s(LeArea), data=mydata_f, method = "REML")
sf3<-summary(modf_3)
modf_4 <- gam(age ~ s(LePer), data=mydata_f, method = "REML")
sf4<-summary(modf_4)
modf_5 <- gam(age ~ s(LieArea), data=mydata_f, method = "REML")
sf5<-summary(modf_5)
modf_6 <- gam(age ~ s(LieAreaRatio), data=mydata_f, method = "REML")
sf6<-summary(modf_6)
modf_7 <- gam(age ~ s(LiArPerIndex), data=mydata_f, method = "REML")
sf7<-summary(modf_7)
modf_8 <- gam(age ~ s(LeArPerIndex), data=mydata_f, method = "REML")
sf8<-summary(modf_8)
modf_9 <- gam(age ~ s(LieArPerIndex), data=mydata_f, method = "REML")
sf9<-summary(modf_9)

## Calculate GAMs predicting age for the females based on upper endplate variables
## and save model summaries
modf_10 <- gam(age ~ s(UiArea), data=mydata_f, method = "REML")
sf10<-summary(modf_10)
modf_11 <- gam(age ~ s(UiPer), data=mydata_f, method = "REML")
sf11<-summary(modf_11)
modf_12 <- gam(age ~ s(UeArea), data=mydata_f, method = "REML")
sf12<-summary(modf_12)
modf_13 <- gam(age ~ s(UePer), data=mydata_f, method = "REML")
sf13<-summary(modf_13)
modf_14 <- gam(age ~ s(UieArea), data=mydata_f, method = "REML")
sf14<-summary(modf_14)
modf_15 <- gam(age ~ s(UieAreaRatio), data=mydata_f, method = "REML")
sf15<-summary(modf_15)
modf_16 <- gam(age ~ s(UiArPerIndex), data=mydata_f, method = "REML")
sf16<-summary(modf_16)
modf_17 <- gam(age ~ s(UeArPerIndex), data=mydata_f, method = "REML")
sf17<-summary(modf_17)
modf_18 <- gam(age ~ s(UieArPerIndex), data=mydata_f, method = "REML")
sf18<-summary(modf_18)

## Plot models for females' lower endplate variables
png("GAM_pAge_Females_Lower.png", width=1500, height=1500, res=300)
grid.arrange(
  ggplot(mydata_f, aes(LiArea, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7))
  + scale_x_continuous(breaks = c(300, 500, 700)),
  ggplot(mydata_f, aes(LiPer, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(LeArea, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7))
  + scale_x_continuous(breaks = c(800, 1000, 1200, 1400)),
  ggplot(mydata_f, aes(LePer, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(LieArea, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7))
  + scale_x_continuous(breaks = c(400, 600, 800)),
  ggplot(mydata_f, aes(LieAreaRatio, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(LiArPerIndex, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(LeArPerIndex, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(LieArPerIndex, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7))
  + scale_x_continuous(breaks = c(0.4, 0.5, 0.6)),
  ncol=3, nrow=3, top ="GAMs predicting age from female lower endplate variables")
dev.off()
## Plot models for females' upper endplate variables
png("GAM_pAge_Females_Upper.png", width=1500, height=1500, res=300)
grid.arrange(
  ggplot(mydata_f, aes(UiArea, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7))
  + scale_x_continuous(breaks = c(400, 500, 600)),
  ggplot(mydata_f, aes(UiPer, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(UeArea, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7))
  + scale_x_continuous(breaks = c(700, 900, 1100, 1300), limits = c(680, 1310)),
  ggplot(mydata_f, aes(UePer, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(UieArea, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7))
  + scale_x_continuous(breaks = c(400, 600, 800)),
  ggplot(mydata_f, aes(UieAreaRatio, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(UiArPerIndex, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(UeArPerIndex, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7)),
  ggplot(mydata_f, aes(UieArPerIndex, age)) + geom_point(size=0.5) + geom_smooth(method = "gam", formula = y ~s(x)) 
  + theme(axis.title.x = element_text(size=8), axis.text.x = element_text(size=7), axis.title.y = element_text(size=8), axis.text.y = element_text(size=7))
  + scale_x_continuous(breaks = c(0.3, 0.4, 0.5)),
  ncol=3, nrow=3, top ="GAMs predicting age from female upper endplate variables")
dev.off()

## Export model statistics to csv
statistics.table4=matrix(data=c(sf1$r.sq, sf1$dev.expl, sf1$chi.sq[[1]], sf1$s.pv, 
                                sf2$r.sq, sf2$dev.expl, sf2$chi.sq[[1]], sf2$s.pv,
                                sf3$r.sq, sf3$dev.expl, sf3$chi.sq[[1]], sf3$s.pv,
                                sf4$r.sq, sf4$dev.expl, sf4$chi.sq[[1]], sf4$s.pv,
                                sf5$r.sq, sf5$dev.expl, sf5$chi.sq[[1]], sf5$s.pv,
                                sf6$r.sq, sf6$dev.expl, sf6$chi.sq[[1]], sf6$s.pv,
                                sf7$r.sq, sf7$dev.expl, sf7$chi.sq[[1]], sf7$s.pv,
                                sf8$r.sq, sf8$dev.expl, sf8$chi.sq[[1]], sf8$s.pv,
                                sf9$r.sq, sf9$dev.expl, sf9$chi.sq[[1]], sf9$s.pv,
                                sf10$r.sq, sf10$dev.expl, sf10$chi.sq[[1]], sf10$s.pv, 
                                sf11$r.sq, sf11$dev.expl, sf11$chi.sq[[1]], sf11$s.pv,
                                sf12$r.sq, sf12$dev.expl, sf12$chi.sq[[1]], sf12$s.pv,
                                sf13$r.sq, sf13$dev.expl, sf13$chi.sq[[1]], sf13$s.pv,
                                sf14$r.sq, sf14$dev.expl, sf14$chi.sq[[1]], sf14$s.pv,
                                sf15$r.sq, sf15$dev.expl, sf15$chi.sq[[1]], sf15$s.pv,
                                sf16$r.sq, sf16$dev.expl, sf16$chi.sq[[1]], sf16$s.pv,
                                sf17$r.sq, sf17$dev.expl, sf17$chi.sq[[1]], sf17$s.pv,
                                sf18$r.sq, sf18$dev.expl, sf18$chi.sq[[1]], sf18$s.pv), nrow=18, ncol=4, byrow=TRUE, 
                        dimnames=list(c("LiArea", "LiPer", "LeArea", "LePer", "LieArea", "LieAreaRatio", "LiArPerIndex", 
                                        "LeArPerIndex", "LieArPerIndex", "UiArea", "UiPer", "UeArea", "UePer", "UieArea",
                                        "UieAreaRatio", "UiArPerIndex", "UeArPerIndex", "UieArPerIndex"), 
                                      c("R2_adj", "Dev. Explained", "F-stat", "p-value")))
write.csv(statistics.table4, file="GAM_pAge_Females.csv")

## Calculate Multivariate GAM for females using LePer, LeArPerIndex, and LieArea variables
multi_fL<-gam(age ~ s(LePer) + s(LeArPerIndex) + s(LieArea), data=mydata_f, method = "REML")
smulti_fL<-summary(multi_fL)

## Calculate Multivariate GAM for females using UePer, UeArea, and UieArea variables
multi_fU<-gam(age ~ s(UePer) + s(UeArea) + s(UieArea), data=mydata_f, method = "REML")
smulti_fU<-summary(multi_fU)


## Export Multivariate GAM statistics to csv
statistics.table5=matrix(data=c(smulti_mL$r.sq, smulti_mL$dev.expl, "LeArPerIndex, LieArea",
                                smulti_fL$r.sq, smulti_fL$dev.expl, "LePer, LeArPerIndex, LieArea",
                                smulti_mU$r.sq, smulti_mU$dev.expl, "UieAreaRatio, UieArea, UeArPerIndex",
                                smulti_fU$r.sq, smulti_fU$dev.expl, "UePer, UeArea, UieArea"),
                                nrow=4, ncol=3, byrow=TRUE,
                        dimnames=list(c("Males_Lower", "Females_Lower", "Males_Upper", "Females_Upper"),
                                     c("R2_adj", "Deviance Explained", "Variables")))
write.csv(statistics.table5, file="GAM_pAge_MulVar.csv")


## Predict age on Danish population and save results to file
mydata <- read_csv("shapeData-DK.csv", show_col_types=FALSE)
pmL<-predict(multi_mL, mydata[mydata$sex==1,c(2,14:22)])
pfL<-predict(multi_fL, mydata[mydata$sex==2,c(2,14:22)])
pmU<-predict(multi_mU, mydata[mydata$sex==1,c(2,5:13)])
pfU<-predict(multi_fU, mydata[mydata$sex==2,c(2,5:13)])
tab_m<-cbind("Sample ID"=mydata$`sample ID`[mydata$sex==1], "Lower Endplate Pred. Age"=pmL, "Upper Endplate Pred. Age"=pmU)
tab_f<-cbind("Sample ID"=mydata$`sample ID`[mydata$sex==2], "Lower Endplate Pred. Age"=pfL, "Upper Endplate Pred. Age"=pfU)
tab_m[is.na(tab_m)] <- NaN
tab_f[is.na(tab_f)] <- NaN
write.csv(tab_m, file="Danish_Predict.csv", quote = FALSE, row.names = FALSE)
write.table(tab_f, file="Danish_Predict.csv", append=TRUE, sep = ",", quote = FALSE, row.names = FALSE, col.names = FALSE)



#### EOF