% script for assessing the predictive capacity of multivariate GAMs on the
% Danish population

% load necessary packages
pkg load io

% read GAM predictions
pred_Age = csv2cell("Danish_Predict.csv")([2:end],[1:3]);

% read inventory of Danish population
inv_D = csv2cell("shapeData-DK.csv")(:,[1:4]);

% evaluate lower endplate
m = 0;
f = 0;
for i = 1:size(pred_Age,1)
  if (isfinite(pred_Age{i,2}))
    age = pred_Age{i,2};
    sID = pred_Age{i,1};
    % find sample's sex and min, max, mean, and range age
    [sex,min,max] = inv_D{find(strcmp(inv_D(:,1), sID)),[2:4]};
    mean = (min + max) / 2;
    range = max - min;
    agmin = age - min;
    agmax = age - max;
    if sex == 1   % males
      m += 1;
      if age < min                        % UnderEstimated
        males_LE(m,:) = [0, agmin, abs((agmin) / range)];
      elseif age > max                    % OverEstimated
        males_LE(m,:) = [0, agmax, agmax / range];
      else                                % WithinRange
        males_LE(m,:) = [1, age - mean, abs((age - mean) / range) * range * 0.2];
      endif
    else          % females
      f += 1;
      if age < min                        % UnderEstimated
        females_LE(f,:) = [0, agmin, abs((agmin) / range)];
      elseif age > max                    % OverEstimated
        females_LE(f,:) = [0, agmax, agmax / range];
      else                                % WithinRange
        females_LE(f,:) = [1, age - mean, abs((age - mean) / range) * range * 0.2];
      endif
    endif
  endif
endfor

% evaluate upper endplate
m = 0;
f = 0;
for i = 1:size(pred_Age,1)
  if (isfinite(pred_Age{i,3}))
    age = pred_Age{i,3};
    sID = pred_Age{i,1};
    % find sample's sex and min, max, mean, and range age
    [sex,min,max] = inv_D{find(strcmp(inv_D(:,1), sID)),[2:4]};
    mean = (min + max) / 2;
    range = max - min;
    agmin = age - min;
    agmax = age - max;
    if sex == 1   % males
      m += 1;
      if age < min                        % UnderEstimated
        males_UE(m,:) = [0, agmin, abs((agmin) / range)];
      elseif age > max                    % OverEstimated
        males_UE(m,:) = [0, agmax, agmax / range];
      else                                % WithinRange
        males_UE(m,:) = [1, age - mean, abs((age - mean) / range) * range * 0.2];
      endif
    else          % females
      f += 1;
      if age < min                        % UnderEstimated
        females_UE(f,:) = [0, agmin, abs((agmin) / range)];
      elseif age > max                    % OverEstimated
        females_UE(f,:) = [0, agmax, agmax / range];
      else                                % WithinRange
        females_UE(f,:) = [1, age - mean, abs((age - mean) / range) * range * 0.2];
      endif
    endif
  endif
endfor

% keep usable variables
clear -x pred_Age males_LE females_LE males_UE females_UE inv_D

% find bin members for under-over-estimated
agebins = [-10, -5, 0, 0, 5, 10, 15, 20, 25, 30, 35, 40, 45, 50];
for i = 1:length(agebins) - 1
  ML_sbin(i,:) = {males_LE(males_LE(:,1)==0 & males_LE(:,2)>agebins(i) & ...
                           males_LE(:,2)<agebins(i+1),3)};
  MU_sbin(i,:) = {males_UE(males_UE(:,1)==0 & males_UE(:,2)>agebins(i) & ...
                           males_UE(:,2)<agebins(i+1),3)};
  FL_sbin(i,:) = {females_LE(females_LE(:,1)==0 & females_LE(:,2)>agebins(i) & ...
                             females_LE(:,2)<agebins(i+1),3)};
  FU_sbin(i,:) = {females_UE(females_UE(:,1)==0 & females_UE(:,2)>agebins(i) & ...
                             females_UE(:,2)<agebins(i+1),3)};
endfor
% find bin members for within-range
ML_sbin(3,:) = {males_LE(males_LE(:,1)==1,3)};
MU_sbin(3,:) = {males_UE(males_UE(:,1)==1,3)};
FL_sbin(3,:) = {females_LE(females_LE(:,1)==1,3)};
FU_sbin(3,:) = {females_UE(females_UE(:,1)==1,3)};

% find sample numbers per range per bin
rangebins = [0, 1, 2, 3, 4, 5, 10];
for i = 1:13
  if length(ML_sbin{i}) > 0
    range = ML_sbin{i};
    for j = 1:length(rangebins) - 1
      ML_Y(i,j) = length(range(range>rangebins(j) & range<=rangebins(j+1)));
    endfor
  else
    ML_Y(i,:) = zeros(1,6);
  endif
  if length(MU_sbin{i}) > 0
    range = MU_sbin{i};
    for j = 1:length(rangebins) - 1
      MU_Y(i,j) = length(range(range>rangebins(j) & range<=rangebins(j+1)));
    endfor
  else
    MU_Y(i,:) = zeros(1,6);
  endif
  if length(FL_sbin{i}) > 0
    range = FL_sbin{i};
    for j = 1:length(rangebins) - 1
      FL_Y(i,j) = length(range(range>rangebins(j) & range<=rangebins(j+1)));
    endfor
  else
    FL_Y(i,:) = zeros(1,6);
  endif
  if length(FU_sbin{i}) > 0
    range = FU_sbin{i};
    for j = 1:length(rangebins) - 1
      FU_Y(i,j) = length(range(range>rangebins(j) & range<=rangebins(j+1)));
    endfor
  else
    FU_Y(i,:) = zeros(1,6);
  endif
endfor

% clear some variables
clear i j range rangebins agebins

% plot stacked histograms with colour coding
xlabels = {"-10 to -5", "-5 to 0", "within range", "0 to 5", "5 to 10", ...
           "10 to 15", "15 to 20", "20 to 25", "25 to 30 ", "30 to 35", ...
           "35 to 40", "40 to 45", "45 to 50"};
tc = {"r", "r", "b", "m", "m", "m", "m", "m", "m", "m", "m", "m", "m"};
rlabels = {" <1 range", "1-2 ranges", "2-3 ranges", "3-4 ranges", "4-5 ranges", " >5 ranges"};
% lower endplate males
figure
subplot(2,2,1)
HML = bar([1:13],ML_Y,0.95,"stacked");
xlim([0, 14]); ylim([0,18]);
title("Male Lower Endplate", "fontsize", 14)
legend (rlabels, "box", "off");
set(gca, "fontsize",12);
for ii = 1:13
  text(ii, -0.3, xlabels{ii}, "rotation", 90, "horizontalalignment", "right",...
        "fontsize", 12, "color", tc{ii})
endfor
text(1,-6.5,"under-\nestimated","fontsize", 8, "horizontalalignment", "center", "color", "r");
text(4,-6.5,"------------- overestimated -------------------","fontsize", 8, "color", "m");
ylabel("individuals");
set(gca, 'xtick', []);
xticklabels ([]);
set(gca, 'position',[0.08 0.65 0.38 0.3]);
% upper endplate males
subplot(2,2,2)
HMU = bar([1:13],MU_Y,0.95,"stacked");
xlim([0, 14]); ylim([0,18]);
title("Male Upper Endplate", "fontsize", 14)
legend (rlabels, "box", "off");
set(gca, "fontsize",12);
for ii = 1:13
  text(ii, -0.3, xlabels{ii}, "rotation", 90, "horizontalalignment", "right",...
        "fontsize", 12, "color", tc{ii})
endfor
text(1,-6.5,"under-\nestimated","fontsize", 8, "horizontalalignment", "center", "color", "r");
text(4,-6.5,"------------- overestimated -------------------","fontsize", 8, "color", "m");
ylabel("individuals");
set(gca, 'xtick', []);
xticklabels ([]);
set(gca, 'position',[0.58 0.65 0.38 0.3]);
% lower endplate females
subplot(2,2,3)
HFL = bar([1:13],FL_Y,0.95,"stacked");
xlim([0, 14]); ylim([0,18]);
title("Female Lower Endplate", "fontsize", 14)
legend (rlabels, "box", "off");
set(gca, "fontsize",12);
for ii = 1:13
  text(ii, -0.3, xlabels{ii}, "rotation", 90, "horizontalalignment", "right",...
        "fontsize", 12, "color", tc{ii})
endfor
text(1,-6.5,"under-\nestimated","fontsize", 8, "horizontalalignment", "center", "color", "r");
text(4,-6.5,"------------- overestimated -------------------","fontsize", 8, "color", "m");
ylabel("individuals");
set(gca, 'xtick', []);
xticklabels ([]);
set(gca, 'position',[0.08 0.15 0.38 0.3]);
% upper endplate females
subplot(2,2,4)
HFU = bar([1:13],FU_Y,0.95,"stacked");
xlim([0, 14]); ylim([0,18]);
title("Female Upper Endplate", "fontsize", 14)
legend (rlabels, "box", "off");
set(gca, "fontsize",12);
for ii = 1:13
  text(ii, -0.3, xlabels{ii}, "rotation", 90, "horizontalalignment", "right",...
        "fontsize", 12, "color", tc{ii})
endfor
text(1,-6.5,"under-\nestimated","fontsize", 8, "horizontalalignment", "center", "color", "r");
text(4,-6.5,"------------- overestimated -------------------","fontsize", 8, "color", "m");
ylabel("individuals");
set(gca, 'xtick', []);
xticklabels ([]);
set(gca, 'position',[0.58 0.15 0.38 0.3]);
print -dpng "-S3000,2800" Predicted_Age.png
close