% script for evaluating intra- and inter-observer error base on the txt files
% available in Intra+Inter folder. Corresponging files are also read from DATA.

% load required package
pkg load io
pkg load statistics

% read intra-inter-observer files and corresponding data from Athens Collection
folder = "Intra+Inter";
files = dir(fullfile(pwd, folder, "ATHE*intra.txt"));
for f = 1:length(files)
  % get numeric sample ID
  sID(f) = str2num(files(f).name([6:9]));
  % get endplate side (Upper = 1; Lower = 2)
  if strcmp(files(f).name(11), "U")
    endPS = 1;
  else
    endPS = 2;
  endif
  % get polyline side (interior = 1; exterior = 2)
  if strcmp(files(f).name(13), "i")
    polyS = 1;
  else
    polyS = 2;
  endif
  % for intra-observer
  % read text file, remove NaNs, and keep x and y coordinates of each point
  a = textread(fullfile(pwd, folder, files(f).name));
  b = a(isfinite(a));
  len = length(b);
  % construct two vectors for polygeom function
  for i = 1:(len-2)/3
    x(i) = b(i*3);
    y(i) = b((i*3)+1);
  endfor
  % calculate area and perimeter
  [geom, iner, cpmo] = polygeom(x, y);
  % save the sample ID, area, and perimeter
  poly1(f,:) = [sID(f), endPS, polyS, geom(1) geom(4)];
  % clear variables
  clear a b len x y geom iner cpmo
  
  % for inter-observer
  % read text file, remove NaNs, and keep x and y coordinates of each point
  a = textread(fullfile(pwd, folder, strcat(files(f).name(1:end-9), "inter.txt")));
  b = a(isfinite(a));
  len = length(b);
  % construct two vectors for polygeom function
  for i = 1:(len-2)/3
    x(i) = b(i*3);
    y(i) = b((i*3)+1);
  endfor
  % calculate area and perimeter
  [geom, iner, cpmo] = polygeom(x, y);
  % save the sample ID, area, and perimeter
  poly2(f,:) = [sID(f), endPS, polyS, geom(1) geom(4)];
  % clear variables
  clear a b len x y geom iner cpmo
  
  % for DATA
  % read text file, remove NaNs, and keep x and y coordinates of each point
  a = textread(fullfile(pwd, "DATA", strcat(files(f).name(1:end-10), ".txt")));
  b = a(isfinite(a));
  len = length(b);
  % construct two vectors for polygeom function
  for i = 1:(len-2)/3
    x(i) = b(i*3);
    y(i) = b((i*3)+1);
  endfor
  % calculate area and perimeter
  [geom, iner, cpmo] = polygeom(x, y);
  % save the sample ID, area, and perimeter
  poly3(f,:) = [sID(f), endPS, polyS, geom(1) geom(4)];
  % clear variables
  clear a b len x y geom iner cpmo endPS polyS
endfor
clear f i files folder
sID=unique(sID);


% calculate morphometric variables for each individual for each available side
snum = 1;
intra = {"sample ID", "UiArea", "UiPer", "UeArea", "UePer",...
          "UieArea", "UieAreaRatio", "UiArPerIndex", "UeArPerIndex", "UieArPerIndex",...
          "LiArea", "LiPer", "LeArea", "LePer", "LieArea", "LieAreaRatio", "LiArPerIndex",...
          "LeArPerIndex", "LieArPerIndex"};
inter = intra;
origD = inter;
for s = 1:length(sID)
  sample_intra = poly1(poly1(:,1)==sID(s),:);
  sample_inter = poly2(poly2(:,1)==sID(s),:);
  sample_origD = poly3(poly3(:,1)==sID(s),:);
  sample_name = cstrcat("ATHE_", char(num2str(sID(s),'%04d')));
  % both sides present
  if size(sample_intra,1) == 4
    Ui_intra = sample_intra(sample_intra(:,2)==1 & sample_intra(:,3)==1, [4:5]);
    Ue_intra = sample_intra(sample_intra(:,2)==1 & sample_intra(:,3)==2, [4:5]);
    Li_intra = sample_intra(sample_intra(:,2)==2 & sample_intra(:,3)==1, [4:5]);
    Le_intra = sample_intra(sample_intra(:,2)==2 & sample_intra(:,3)==2, [4:5]);
    Ui_inter = sample_inter(sample_inter(:,2)==1 & sample_inter(:,3)==1, [4:5]);
    Ue_inter = sample_inter(sample_inter(:,2)==1 & sample_inter(:,3)==2, [4:5]);
    Li_inter = sample_inter(sample_inter(:,2)==2 & sample_inter(:,3)==1, [4:5]);
    Le_inter = sample_inter(sample_inter(:,2)==2 & sample_inter(:,3)==2, [4:5]);
    Ui_origD = sample_origD(sample_origD(:,2)==1 & sample_origD(:,3)==1, [4:5]);
    Ue_origD = sample_origD(sample_origD(:,2)==1 & sample_origD(:,3)==2, [4:5]);
    Li_origD = sample_origD(sample_origD(:,2)==2 & sample_origD(:,3)==1, [4:5]);
    Le_origD = sample_origD(sample_origD(:,2)==2 & sample_origD(:,3)==2, [4:5]);
    intraData(snum,:) = [Ui_intra(1), Ui_intra(2), Ue_intra(1), Ue_intra(2),...
                 Ue_intra(1)-Ui_intra(1), (Ue_intra(1)-Ui_intra(1))/Ue_intra(1),...
                 (Ui_intra(1)*4*pi)/(Ui_intra(2)^2),...
                 (Ue_intra(1)*4*pi)/(Ue_intra(2)^2),...
                 ((Ue_intra(1)-Ui_intra(1))*4*pi)/(Ue_intra(2)^2),...
                 Li_intra(1), Li_intra(2), Le_intra(1), Le_intra(2),...
                 Le_intra(1)-Li_intra(1), (Le_intra(1)-Li_intra(1))/Le_intra(1),...
                 (Li_intra(1)*4*pi)/(Li_intra(2)^2),...
                 (Le_intra(1)*4*pi)/(Le_intra(2)^2),...
                 ((Le_intra(1)-Li_intra(1))*4*pi)/(Le_intra(2)^2)];
    interData(snum,:) = [Ui_inter(1), Ui_inter(2), Ue_inter(1), Ue_inter(2),...
                 Ue_inter(1)-Ui_inter(1), (Ue_inter(1)-Ui_inter(1))/Ue_inter(1),...
                 (Ui_inter(1)*4*pi)/(Ui_inter(2)^2),...
                 (Ue_inter(1)*4*pi)/(Ue_inter(2)^2),...
                 ((Ue_inter(1)-Ui_inter(1))*4*pi)/(Ue_inter(2)^2),...
                 Li_inter(1), Li_inter(2), Le_inter(1), Le_inter(2),...
                 Le_inter(1)-Li_inter(1), (Le_inter(1)-Li_inter(1))/Le_inter(1),...
                 (Li_inter(1)*4*pi)/(Li_inter(2)^2),...
                 (Le_inter(1)*4*pi)/(Le_inter(2)^2),...
                 ((Le_inter(1)-Li_inter(1))*4*pi)/(Le_inter(2)^2)];
    origData(snum,:) = [Ui_origD(1), Ui_origD(2), Ue_origD(1), Ue_origD(2),...
               Ue_origD(1)-Ui_origD(1), (Ue_origD(1)-Ui_origD(1))/Ue_origD(1),...
               (Ui_origD(1)*4*pi)/(Ui_origD(2)^2),...
               (Ue_origD(1)*4*pi)/(Ue_origD(2)^2),...
               ((Ue_origD(1)-Ui_origD(1))*4*pi)/(Ue_origD(2)^2),...
               Li_origD(1), Li_origD(2), Le_origD(1), Le_origD(2),...
               Le_origD(1)-Li_origD(1), (Le_origD(1)-Li_origD(1))/Le_origD(1),...
               (Li_origD(1)*4*pi)/(Li_origD(2)^2),...
               (Le_origD(1)*4*pi)/(Le_origD(2)^2),...
               ((Le_origD(1)-Li_origD(1))*4*pi)/(Le_origD(2)^2)];
    snum += 1;
    intra(snum,:) = {sample_name, Ui_intra(1), Ui_intra(2), Ue_intra(1), Ue_intra(2),...
                     Ue_intra(1)-Ui_intra(1), (Ue_intra(1)-Ui_intra(1))/Ue_intra(1),...
                     (Ui_intra(1)*4*pi)/(Ui_intra(2)^2),...
                     (Ue_intra(1)*4*pi)/(Ue_intra(2)^2),...
                     ((Ue_intra(1)-Ui_intra(1))*4*pi)/(Ue_intra(2)^2),...
                     Li_intra(1), Li_intra(2), Le_intra(1), Le_intra(2),...
                     Le_intra(1)-Li_intra(1), (Le_intra(1)-Li_intra(1))/Le_intra(1),...
                     (Li_intra(1)*4*pi)/(Li_intra(2)^2),...
                     (Le_intra(1)*4*pi)/(Le_intra(2)^2),...
                     ((Le_intra(1)-Li_intra(1))*4*pi)/(Le_intra(2)^2)};
    inter(snum,:) = {sample_name, Ui_inter(1), Ui_inter(2), Ue_inter(1), Ue_inter(2),...
                     Ue_inter(1)-Ui_inter(1), (Ue_inter(1)-Ui_inter(1))/Ue_inter(1),...
                     (Ui_inter(1)*4*pi)/(Ui_inter(2)^2),...
                     (Ue_inter(1)*4*pi)/(Ue_inter(2)^2),...
                     ((Ue_inter(1)-Ui_inter(1))*4*pi)/(Ue_inter(2)^2),...
                     Li_inter(1), Li_inter(2), Le_inter(1), Le_inter(2),...
                     Le_inter(1)-Li_inter(1), (Le_inter(1)-Li_inter(1))/Le_inter(1),...
                     (Li_inter(1)*4*pi)/(Li_inter(2)^2),...
                     (Le_inter(1)*4*pi)/(Le_inter(2)^2),...
                     ((Le_inter(1)-Li_inter(1))*4*pi)/(Le_inter(2)^2)};
    origD(snum,:) = {sample_name, Ui_origD(1), Ui_origD(2), Ue_origD(1), Ue_origD(2),...
                     Ue_origD(1)-Ui_origD(1), (Ue_origD(1)-Ui_origD(1))/Ue_origD(1),...
                     (Ui_origD(1)*4*pi)/(Ui_origD(2)^2),...
                     (Ue_origD(1)*4*pi)/(Ue_origD(2)^2),...
                     ((Ue_origD(1)-Ui_origD(1))*4*pi)/(Ue_origD(2)^2),...
                     Li_origD(1), Li_origD(2), Le_origD(1), Le_origD(2),...
                     Le_origD(1)-Li_origD(1), (Le_origD(1)-Li_origD(1))/Le_origD(1),...
                     (Li_origD(1)*4*pi)/(Li_origD(2)^2),...
                     (Le_origD(1)*4*pi)/(Le_origD(2)^2),...
                     ((Le_origD(1)-Li_origD(1))*4*pi)/(Le_origD(2)^2)};
  % only upper endplate
  elseif size(sample_intra,1) == 2 && sample_intra(1,2) == 1
    Ui_intra = sample_intra(sample_intra(:,2)==1 & sample_intra(:,3)==1, [4:5]);
    Ue_intra = sample_intra(sample_intra(:,2)==1 & sample_intra(:,3)==2, [4:5]);
    Ui_inter = sample_inter(sample_inter(:,2)==1 & sample_inter(:,3)==1, [4:5]);
    Ue_inter = sample_inter(sample_inter(:,2)==1 & sample_inter(:,3)==2, [4:5]);
    Ui_origD = sample_origD(sample_origD(:,2)==1 & sample_origD(:,3)==1, [4:5]);
    Ue_origD = sample_origD(sample_origD(:,2)==1 & sample_origD(:,3)==2, [4:5]);
    intraData(snum,:) = [Ui_intra(1), Ui_intra(2), Ue_intra(1), Ue_intra(2),...
                 Ue_intra(1)-Ui_intra(1), (Ue_intra(1)-Ui_intra(1))/Ue_intra(1),...
                 (Ui_intra(1)*4*pi)/(Ui_intra(2)^2),...
                 (Ue_intra(1)*4*pi)/(Ue_intra(2)^2),...
                 ((Ue_intra(1)-Ui_intra(1))*4*pi)/(Ue_intra(2)^2),...
                 NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN];
    interData(snum,:) = [Ui_inter(1), Ui_inter(2), Ue_inter(1), Ue_inter(2),...
                 Ue_inter(1)-Ui_inter(1), (Ue_inter(1)-Ui_inter(1))/Ue_inter(1),...
                 (Ui_inter(1)*4*pi)/(Ui_inter(2)^2),...
                 (Ue_inter(1)*4*pi)/(Ue_inter(2)^2),...
                 ((Ue_inter(1)-Ui_inter(1))*4*pi)/(Ue_inter(2)^2),...
                 NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN];
    origData(snum,:) = [Ui_origD(1), Ui_origD(2), Ue_origD(1), Ue_origD(2),...
               Ue_origD(1)-Ui_origD(1), (Ue_origD(1)-Ui_origD(1))/Ue_origD(1),...
               (Ui_origD(1)*4*pi)/(Ui_origD(2)^2),...
               (Ue_origD(1)*4*pi)/(Ue_origD(2)^2),...
               ((Ue_origD(1)-Ui_origD(1))*4*pi)/(Ue_origD(2)^2),...
               NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN];
    snum += 1;
    intra(snum,:) = {sample_name, Ui_intra(1), Ui_intra(2), Ue_intra(1), Ue_intra(2),...
                     Ue_intra(1)-Ui_intra(1), (Ue_intra(1)-Ui_intra(1))/Ue_intra(1),...
                     (Ui_intra(1)*4*pi)/(Ui_intra(2)^2),...
                     (Ue_intra(1)*4*pi)/(Ue_intra(2)^2),...
                     ((Ue_intra(1)-Ui_intra(1))*4*pi)/(Ue_intra(2)^2),...
                     NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN};
    inter(snum,:) = {sample_name, Ui_inter(1), Ui_inter(2), Ue_inter(1), Ue_inter(2),...
                     Ue_inter(1)-Ui_inter(1), (Ue_inter(1)-Ui_inter(1))/Ue_inter(1),...
                     (Ui_inter(1)*4*pi)/(Ui_inter(2)^2),...
                     (Ue_inter(1)*4*pi)/(Ue_inter(2)^2),...
                     ((Ue_inter(1)-Ui_inter(1))*4*pi)/(Ue_inter(2)^2),...
                     NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN};
    origD(snum,:) = {sample_name, Ui_origD(1), Ui_origD(2), Ue_origD(1), Ue_origD(2),...
                     Ue_origD(1)-Ui_origD(1), (Ue_origD(1)-Ui_origD(1))/Ue_origD(1),...
                     (Ui_origD(1)*4*pi)/(Ui_origD(2)^2),...
                     (Ue_origD(1)*4*pi)/(Ue_origD(2)^2),...
                     ((Ue_origD(1)-Ui_origD(1))*4*pi)/(Ue_origD(2)^2),...
                     NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN};
  % only lower endplate
  elseif size(sample_intra,1) == 2 && sample_intra(1,2) == 2
    Li_intra = sample_intra(sample_intra(:,2)==2 & sample_intra(:,3)==1, [4:5]);
    Le_intra = sample_intra(sample_intra(:,2)==2 & sample_intra(:,3)==2, [4:5]);
    Li_inter = sample_inter(sample_inter(:,2)==2 & sample_inter(:,3)==1, [4:5]);
    Le_inter = sample_inter(sample_inter(:,2)==2 & sample_inter(:,3)==2, [4:5]);
    Li_origD = sample_origD(sample_origD(:,2)==2 & sample_origD(:,3)==1, [4:5]);
    Le_origD = sample_origD(sample_origD(:,2)==2 & sample_origD(:,3)==2, [4:5]);
    intraData(snum,:) = [NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN,...
                 Li_intra(1), Li_intra(2), Le_intra(1), Le_intra(2),...
                 Le_intra(1)-Li_intra(1), (Le_intra(1)-Li_intra(1))/Le_intra(1),...
                 (Li_intra(1)*4*pi)/(Li_intra(2)^2),...
                 (Le_intra(1)*4*pi)/(Le_intra(2)^2),...
                 ((Le_intra(1)-Li_intra(1))*4*pi)/(Le_intra(2)^2)];
    interData(snum,:) = [NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN,...
                 Li_inter(1), Li_inter(2), Le_inter(1), Le_inter(2),...
                 Le_inter(1)-Li_inter(1), (Le_inter(1)-Li_inter(1))/Le_inter(1),...
                 (Li_inter(1)*4*pi)/(Li_inter(2)^2),...
                 (Le_inter(1)*4*pi)/(Le_inter(2)^2),...
                 ((Le_inter(1)-Li_inter(1))*4*pi)/(Le_inter(2)^2)];
    origData(snum,:) = [NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN,...
               Li_origD(1), Li_origD(2), Le_origD(1), Le_origD(2),...
               Le_origD(1)-Li_origD(1), (Le_origD(1)-Li_origD(1))/Le_origD(1),...
               (Li_origD(1)*4*pi)/(Li_origD(2)^2),...
               (Le_origD(1)*4*pi)/(Le_origD(2)^2),...
               ((Le_origD(1)-Li_origD(1))*4*pi)/(Le_origD(2)^2)];
    snum += 1;
    intra(snum,:) = {sample_name, NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN,...
                     Li_intra(1), Li_intra(2), Le_intra(1), Le_intra(2),...
                     Le_intra(1)-Li_intra(1), (Le_intra(1)-Li_intra(1))/Le_intra(1),...
                     (Li_intra(1)*4*pi)/(Li_intra(2)^2),...
                     (Le_intra(1)*4*pi)/(Le_intra(2)^2),...
                     ((Le_intra(1)-Li_intra(1))*4*pi)/(Le_intra(2)^2)};
    inter(snum,:) = {sample_name, NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN,...
                     Li_inter(1), Li_inter(2), Le_inter(1), Le_inter(2),...
                     Le_inter(1)-Li_inter(1), (Le_inter(1)-Li_inter(1))/Le_inter(1),...
                     (Li_inter(1)*4*pi)/(Li_inter(2)^2),...
                     (Le_inter(1)*4*pi)/(Le_inter(2)^2),...
                     ((Le_inter(1)-Li_inter(1))*4*pi)/(Le_inter(2)^2)};
    origD(snum,:) = {sample_name, NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN,...
                     Li_origD(1), Li_origD(2), Le_origD(1), Le_origD(2),...
                     Le_origD(1)-Li_origD(1), (Le_origD(1)-Li_origD(1))/Le_origD(1),...
                     (Li_origD(1)*4*pi)/(Li_origD(2)^2),...
                     (Le_origD(1)*4*pi)/(Le_origD(2)^2),...
                     ((Le_origD(1)-Li_origD(1))*4*pi)/(Le_origD(2)^2)};
  endif
  clear -x poly1 poly2 poly3 intraData interData origData intra inter origD s sID snum
endfor
clear s sID snum

% calculate TEM for intra-observer error
sum_diff = (origData-intraData).^2;
n = sum(~isnan(sum_diff),1);
intraTEM = sqrt(nansum(sum_diff)./(2.*n));
VAV = nanmean([origData;intraData]);
intraTEMr = (intraTEM ./ VAV) * 100;
intraR = 1 - ((intraTEM.^2)./(nanstd([origData;intraData]).^2));

% calculate TEM for inter-observer error
sum_diff = (origData-interData).^2;
n = sum(~isnan(sum_diff),1);
interTEM = sqrt(nansum(sum_diff)./(2.*n));
VAV = nanmean([origData;interData]);
interTEMr = (interTEM ./ VAV) * 100;
interR = 1 - ((interTEM.^2)./(nanstd([origData;interData]).^2));

% save results to csv file
results = [intraTEM',intraTEMr',intraR',interTEM',interTEMr',interR'];
outputT = {"Morphometric Variables", "intraTEM", "intraTEMr", "intraR",...
           "interTEM" ,"interTEMr", "interR"};
outputT = [outputT; intra(1,[2:end])', num2cell(results)];
cell2csv("Observer_Error.csv", outputT);