% script for ploting each shape variable of the upper and lower endplates of the
% T12 against age. Each variable is plotted on different subplot and sexes are
% represented by different colours.

% load necessary package
pkg load io

% load data for Greek population
data = csv2cell("shapeData-GR.csv");
Mvar = data(1,[4:end]);
unit = {"mm^2", "mm", "mm^2", "mm", "mm^2", "ratio", "ratio", "ratio", "ratio"};
data = csvread("shapeData-GR.csv");
data(:,1) = [];
data(1,:) = [];
% order samples by age
data = sortrows(data, 2);
sex = data(:,1);
age = data(:,2);
% group by sex
Mdata = data(sex == 1,[3:end]);
M_age = data(sex == 1,2);
Fdata = data(sex == 2,[3:end]);
F_age = data(sex == 2,2);

% create subplots for upper endplates
for i=1:9
  h(i) = subplot(3, 3, i);
  plot(h(i), M_age, Mdata(:,i), "ob", "markersize" , 5);
  hold on
  plot(h(i), F_age, Fdata(:,i), "*r", "markersize" , 5);
  set(gca, "fontsize",8);
  xlabel("age", "fontsize", 10, "fontangle", "italic");
  ylabel(unit{i}, "fontsize", 10, "fontangle", "italic");
  title(Mvar{i}, "fontsize", 10);
  set (gca, "xgrid", "on");
  set (gca, "yminorgrid", "on");
  hold off
endfor

% add main title and legend
hold on
axes( 'visible', 'off');
text(0.5, 1.05, 'Morphometric variables of Upper Endplates for Greek population',...
     "fontsize", 13, "fontweight", "bold", "horizontalalignment", "center");
text(0.4, -0.08, 'Males ^o', "fontsize", 13, "color", "blue", "horizontalalignment", "center");
text(0.6, -0.08, 'Females *', "fontsize", 13, "color", "red", "horizontalalignment", "center");
hold off
% print to file
print -dpng "-S1500, 1500" GR_UpperEndplate.png
close

% create subplots for lower endplates
for i=10:18
  h(i) = subplot(3, 3, i-9);
  plot(h(i), M_age, Mdata(:,i), "ob", "markersize" , 5);
  hold on
  plot(h(i), F_age, Fdata(:,i), "*r", "markersize" , 5);
  set(gca, "fontsize",8);
  xlabel("age", "fontsize", 10, "fontangle", "italic");
  ylabel(unit{i-9}, "fontsize", 10, "fontangle", "italic");
  title(Mvar{i}, "fontsize", 10);
  set (gca, "xgrid", "on");
  set (gca, "yminorgrid", "on");
  hold off
endfor

% add main title and legend
hold on
axes( 'visible', 'off');
text(0.5, 1.05, 'Morphometric variables of Lower Endplates for Greek population',...
     "fontsize", 13, "fontweight", "bold", "horizontalalignment", "center");
text(0.4, -0.08, 'Males ^o', "fontsize", 13, "color", "blue", "horizontalalignment", "center");
text(0.6, -0.08, 'Females *', "fontsize", 13, "color", "red", "horizontalalignment", "center");
hold off
% print to file
print -dpng "-S1500, 1500" GR_LowerEndplate.png
close



% load data for Danish population
data = csv2cell("shapeData-DK.csv");
Mvar = data(1,[5:end]);
unit = {"mm^2", "mm", "mm^2", "mm", "mm^2", "ratio", "ratio", "ratio", "ratio"};
data = csvread("shapeData-DK.csv");
data(:,1) = [];
data(1,:) = [];
% order samples by mean age range
data(:,2) = (data(:,2) + data(:,3)) ./ 2;
data = sortrows(data, 2);
sex = data(:,1);
age = data(:,2);
% group by sex
Mdata = data(sex == 1,[4:end]);
M_age = data(sex == 1,2);
Fdata = data(sex == 2,[4:end]);
F_age = data(sex == 2,2);
% create subplots for upper endplates
for i=1:9
  h(i) = subplot(3, 3, i);
  plot(h(i), M_age, Mdata(:,i), "ob", "markersize" , 5);
  hold on
  plot(h(i), F_age, Fdata(:,i), "*r", "markersize" , 5);
  set(gca, "fontsize",8);
  xlabel("age", "fontsize", 10, "fontangle", "italic");
  ylabel(unit{i}, "fontsize", 10, "fontangle", "italic");
  title(Mvar{i}, "fontsize", 10);
  set (gca, "xgrid", "on");
  set (gca, "yminorgrid", "on");
  hold off
endfor

% add main title and legend
hold on
axes( 'visible', 'off');
text(0.5, 1.05, 'Morphometric variables of Upper Endplates for Danish population',...
     "fontsize", 13, "fontweight", "bold", "horizontalalignment", "center");
text(0.4, -0.08, 'Males ^o', "fontsize", 13, "color", "blue", "horizontalalignment", "center");
text(0.6, -0.08, 'Females *', "fontsize", 13, "color", "red", "horizontalalignment", "center");
hold off
% print to file
print -dpng "-S1500, 1500" DK_UpperEndplate.png
close

% create subplots for lower endplates
for i=10:18
  h(i) = subplot(3, 3, i-9);
  plot(h(i), M_age, Mdata(:,i), "ob", "markersize" , 5);
  hold on
  plot(h(i), F_age, Fdata(:,i), "*r", "markersize" , 5);
  set(gca, "fontsize",8);
  xlabel("age", "fontsize", 10, "fontangle", "italic");
  ylabel(unit{i-9}, "fontsize", 10, "fontangle", "italic");
  title(Mvar{i}, "fontsize", 10);
  set (gca, "xgrid", "on");
  set (gca, "yminorgrid", "on");
  hold off
endfor

% add main title and legend
hold on
axes( 'visible', 'off');
text(0.5, 1.05, 'Morphometric variables of Lower Endplates for Danish population',...
     "fontsize", 13, "fontweight", "bold", "horizontalalignment", "center");
text(0.4, -0.08, 'Males ^o', "fontsize", 13, "color", "blue", "horizontalalignment", "center");
text(0.6, -0.08, 'Females *', "fontsize", 13, "color", "red", "horizontalalignment", "center");
hold off
% print to file
print -dpng "-S1500, 1500" DK_LowerEndplate.png
close