% script for ploting age-at-death distributions from Greek and Danish samples.
% Distributions are separated (stacked) by sex.

% load data
GR = csvread("shapeData-GR.csv")([2:end],[2:3]);
DK = csvread("shapeData-DK.csv")([2:end],[2:4]);
DK(:,2) = mean([DK(:,2), DK(:,3)],2);
DK(:,3) = [];

% fontsize
fs = 12;

% create histogram for Greeks
subplot(2,1,1);
[indn, binc] = hist(GR(:,2));
[indm, binm] = hist(GR(GR(:,1) == 1, 2), binc);
[indf, binf] = hist(GR(GR(:,1) == 2, 2), binc);
bGR = bar(binc, [indm', indf'], "stacked", 1);
set(get(gcf, "currentaxes"), "fontsize", fs);
set(bGR(1), "facecolor", "r");
set(bGR(2), "facecolor", "g");

lGR = legend("males", "females", "location", "northeast");
legend boxoff;
set(lGR, "fontsize", fs-2);
set(lGR, "fontangle", "italic");
set(lGR, "position", [0.78,	0.80,	0.1, 0.06]);
axis([15,100,0,35]);
xlabel("age-at-death (years)", "fontsize", fs);
ylabel("individuals", "fontsize", fs);
title("Greek sample", "fontsize", fs+8);

% create histogram for Danes
subplot(2,1,2);
%[indn, binc] = hist(DK(:,2));
[indm, binm] = hist(DK(DK(:,1) == 1, 2), binc);
[indf, binf] = hist(DK(DK(:,1) == 2, 2), binc);
bDK = bar(binc, [indf', indm'], "stacked", 1);
set(get(gcf, "currentaxes"), "fontsize", fs);
set(bDK(1), "facecolor", "r");
set(bDK(2), "facecolor", "g");

lDK = legend("males", "females", "location", "northeast");
legend boxoff;
set(lDK, "fontsize", fs-2);
set(lDK, "fontangle", "italic");
set(lDK, "position", [0.78,	0.32,	0.1, 0.06]);
axis([15,100,0,35]);
xlabel("age-at-death (years)", "fontsize", fs);
ylabel("individuals", "fontsize", fs);
title("Danish sample", "fontsize", fs+8);

% export plot
print -dpng "-S1200, 700" Sample_Descriptives.png
close