% a script for running the entire analysis on vertebral endplates
% the 'io' and 'statistics' packages must be installed!
pkg load io
pkg load statistics
clear

% read 2D polyline coordinates from files in the DATA folder, calculate
% morphometric variables for upper and lower endplates and aggregate them
% in a separate file for each population
make_data
% Filenames: shapeData-DK.csv, shapeData-GR.csv
clear

% plot sample descriptives with respect to sex and age-at-death and save figure
plot_sample
% Filename: Sample_age.png
clear

% calculate intra- and inter-observer error on the subset of vertebral endplates
% in the Intra+Inter folder and aggregate results in a file
observer_error
% Filename: Observer_Error.csv
clear

% check data for expression of sexual dimorphism by means of either one-way
% ANOVA or Kruskal-Wallis test along with the appropriate size effect estimator
% and save results in a file
sex_dimorphism
% Filename: Sex_Dimorphism.csv
clear

% plot the aggregated data in scatter plots grouped by population and side and
% save figures (they are used as supplementary material)
plot_data
% Filenames: DK_LowerEndplate.png, DK_UpperEndplate.png
%            GR_LowerEndplate.png, GR_UpperEndplate.png
clear

% Run analysis in R
s = unix("Rscript GAM_analysis.R");
% Filenames: GAM_pAge_Males_Lower.png, GAM_pAge_Females_Lower.png
%            GAM_pAge_Males_Upper.png, GAM_pAge_Females_Upper.png
%            GAM_pVar_Males_Lower.png, GAM_pVar_Females_Lower.png
%            GAM_pVar_Males_Upper.png, GAM_pVar_Females_Upper.png
%            GAM_pVal_Best_Models_per_Sex.png
%            GAM_pAge_Males.csv, GAM_pAge_Females.csv, GAM_pAge_MulVar.csv
%            GAM_pVar_Males.csv, GAM_pVar_Females.csv
%            Danish_Predict.csv
clear

% evaluate GAMs on the Danish sample and plot histogram on pregicted age
evaluate_GAMs
% Filenames: Predicted_Age.png
clear